{% if config.email_subject != None %}
From: {{ config.email_from }}
To: {{ config.email_to }}
{% if config.email_cc != None %}
Cc: {{ config.email_cc }}
{% endif %}
Subject:
{{- " [REGRESSION]" if has_regressions }}
{{- " %s" % (config.email_subject) }}

{% endif %}
